@@ -9,10 +9,10 @@ from functools import lru_cache
 from os.path import abspath, dirname
 # import awswrangler as wr
 from typing import Dict
-from black import FileMode, format_str
 
 import findspark
 import tomlkit
+from black import FileMode, format_str
 
 
 REQUIRED_PARAM = ["s3-staging-dir", "cluster-name", "stage", "region"]
@@ -61,11 +61,7 @@ kdf = pd.DataFrame(
  'b': [100, 200, 300, 400, 500, 600],
  'c': ["one", "two", "three", "four", "five", "six"]},
 index=[10, 20, 30, 40, 50, 60])
-
-print('Number of arguments:', len(sys.argv) )
-print('Argument List:', str(sys.argv))
-print("N-rows", len(kdf))
-
+print("Fin.")
 """.strip()
 
 MAC_SPARK_DIR = "/usr/local/Cellar/apache-spark"
@@ -111,24 +107,24 @@ def append_git_ignore(git_ignore_path=".gitignore"):
 
     """
 
-    with open(git_ignore_path) as f:
-        git_ignore = f.read()
+    with open(git_ignore_path) as file:
+        git_ignore = file.read()
 
     git_ignore = git_ignore.split("\n")
     for pattern in GIT_IGNORE_PATTERNS:
         if pattern not in git_ignore:
             git_ignore.append(pattern)
 
-    with open(git_ignore_path, "w") as f:
-        f.write("\n".join(git_ignore))
+    with open(git_ignore_path, "w") as file:
+        file.write("\n".join(git_ignore))
 
 
 def create_git_ignore():
     """Creates git ignore if it doesn't exist."""
     git_ignore_path = ".gitignore"
     if not os.path.isfile(git_ignore_path):
-        with open(git_ignore_path, "w") as f:
-            f.write("\n".join(GIT_IGNORE_PATTERNS))
+        with open(git_ignore_path, "w") as file:
+            file.write("\n".join(GIT_IGNORE_PATTERNS))
     else:
         append_git_ignore(git_ignore_path)
 
@@ -195,6 +191,18 @@ def get_project_attributes(keys: list):
       keys: list:
       keys: list:
       keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
 
     Returns:
 
@@ -224,7 +232,7 @@ def get_email(author):
 
 
 def get_emails():
-    """ """
+    """Extract emails from project owners."""
     res = []
     authos = get_project_attribute("authors")
     for author in authos:
@@ -274,6 +282,18 @@ def get_cluster_name(cluster_name: str = "default"):
       cluster_name: str:  (Default value = "default")
       cluster_name: str:  (Default value = "default")
       cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
 
     Returns:
 
@@ -291,8 +311,8 @@ def get_version():
     if _pyproject_toml_exists():
         config = _get_pyproject_toml()
         return config["tool"]["poetry"]["version"]
-    else:
-        return cinput("Version", "v1")
+
+    return cinput("Version", "v1")
 
 
 @lru_cache()
@@ -329,14 +349,6 @@ def get_project_type(toml_path: str = DEFAULT_TOML_PATH):
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -356,14 +368,6 @@ def _pyproject_toml_exists(pyproj_path: str = DEFAULT_TOML_PATH):
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -377,17 +381,6 @@ def _get_pyproject_toml(pyproj_path: str = DEFAULT_TOML_PATH) -> Dict[str, str]:
     Args:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
       dict: Project toml param.
@@ -418,22 +411,6 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = DEFAULT_TOML_P
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
       file_contents: dict:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -564,9 +541,9 @@ def init_pyemr_param(cluster_name, s3_stage_dir, stage, region):
                 value = default_value
             tml["tool"]["pyemr"][variable_name] = value
 
-    #print("[tool.pyemr]")
-    #print(tomlkit.dumps(tml["tool"]["pyemr"]))
-    
+    # print("[tool.pyemr]")
+    # print(tomlkit.dumps(tml["tool"]["pyemr"]))
+
     _write_pyproject_toml(tml)
 
 
@@ -579,14 +556,6 @@ def add_dependencies(dependencies: list):
       dependencies: list:
       dependencies: list:
       dependencies: list:
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
 
     Returns:
 
@@ -652,8 +621,8 @@ def create_koalas_example(out_path):
 
     path = f"{out_path}/script.py"
     if not os.path.isfile(path):
-        with open(path, "w") as f:
-            f.write(example_script)
+        with open(path, "w") as file:
+            file.write(example_script)
 
 
 def add_main_package():
@@ -706,8 +675,8 @@ def init_pyemr(project_name, cluster_name, s3_stage_dir, stage, region):
             project_name,
             "--quiet",
         ] + dep
-        proc = subprocess.Popen(args)
-        proc.communicate()
+        with subprocess.Popen(args) as proc:
+            proc.communicate()
 
     # install default dependencies
     # add_dependencies(DEFAULT_DEPENDENCIES)
