@@ -1,15 +1,18 @@
 """A collection of aws tools"""
 import os
-import time
 import subprocess
+import time
 from pathlib import Path
-from subprocess import STDOUT, check_output, TimeoutExpired
+from subprocess import STDOUT, TimeoutExpired, check_output
+
+import docker
 
 from pyemr.utils.sys import is_port_in_use, pipe_cmd
 
-from .config import cprint, get_config_attr, get_package_dir,cinput
+from .config import cinput, cprint, get_config_attr, get_package_dir
 
-SH_DIR_DOCKER = '/pyemr/files/sh'
+
+SH_DIR_DOCKER = "/pyemr/files/sh"
 AMAZON_LINUX_DOCKER_TAG = "pyemr/amazonlinux:latest"
 AMAZON_LINUX_DOCKER_FILE = "files/docker/amazonlinux.spark{spark_version}.Dockerfile"
 
@@ -76,6 +79,7 @@ def docker_build(
       dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
       dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
       dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
+      dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
 
     Returns:
 
@@ -90,7 +94,7 @@ def docker_build(
         raise ValueError(
             f"No docker image found for spark {spark_version}. Create a new docker file called '{project_dir}/{dockerfile}'.",
         )
-    
+
     if is_docker_build(tag_name) == False:
         cprint(
             f"WARNING:This is the first time you using pyemr or '{dockerfile}'. It might take ~5 minutes.",
@@ -141,22 +145,27 @@ def docker_run_sh(
     """
     if p:
         out_port = int(p.split(":")[-1])
-        
+
         if is_port_in_use(out_port):
-            print('\n')
-            cprint( f"Port {out_port} already in use. Stopping all other pyemr sessions...", 'FAIL')
-            cprint( f"(otherwise press ^C)", 'FAIL')
+            print("\n")
+            cprint(
+                f"Port {out_port} already in use. Stopping all other pyemr sessions...",
+                "FAIL",
+            )
+            cprint("(otherwise press ^C)", "FAIL")
             time.sleep(5)
-        
+
         if is_port_in_use(out_port):
             stop_pyemr_containers()
-            #reply = cinput('\t Stop all other pyemr notebooks/containers', 'y' )
-            #if reply in ['y', 'Y','Yes', 'YES' ]:
-            #else:
-        
+            # reply = cinput('\t Stop all other pyemr notebooks/containers', 'y' )
+            # if reply in ['y', 'Y','Yes', 'YES' ]:
+            # else:
+
         if is_port_in_use(out_port):
-            raise ValueError(f"Port {out_port} is already in use. Do you have pyemr container already running? Try 'docker container list', then 'docker stop'.")
-    
+            raise ValueError(
+                f"Port {out_port} is already in use. Do you have pyemr container already running? Try 'docker container list', then 'docker stop'.",
+            )
+
     home = str(Path.home())
     pwd_mount = f'src="{mount_dir}",target=/app,type=bind'
     aws_mount = f"src={home}/.aws/credentials,target=/root/.aws/credentials,type=bind"
@@ -171,27 +180,37 @@ def docker_run_sh(
     pipe_cmd(cmd)
 
 
-import pandas as pd
-import docker
-
 def docker_containers_list():
+    """ """
     client = docker.from_env()
     for container in client.containers.list():
-        if 'pyemr' in container.attrs['Config']['Image']:
+        if "pyemr" in container.attrs["Config"]["Image"]:
             yield container
-            
 
 
 def stop_pyemr_containers():
+    """ """
     for c in docker_containers_list():
         c.stop()
 
 
-def is_check_docker_engine_responding(seconds = 6):
+def is_check_docker_engine_responding(seconds=6):
+    """
+
+    Args:
+      seconds: (Default value = 6)
+
+    Returns:
+
+    """
     try:
         seconds = 6
-        output = check_output(['docker', 'container', 'ls'] , stderr=STDOUT, timeout=seconds)
-        if not 'CONTAINER ID' in output.decode():
+        output = check_output(
+            ["docker", "container", "ls"],
+            stderr=STDOUT,
+            timeout=seconds,
+        )
+        if not "CONTAINER ID" in output.decode():
             print(output.decode())
             return False
         return True
@@ -200,9 +219,8 @@ def is_check_docker_engine_responding(seconds = 6):
 
 
 def docker_engine_warning():
+    """ """
     if not is_check_docker_engine_responding(30):
-        resp = cinput("Docker not responding. Restart docker engine?", 'n')
-        if resp in ['y','Y',True,'yes','YES','Yes','true','True']:
-            pipe_cmd('killall Docker && open /Applications/Docker.app')
-
-
+        resp = cinput("Docker not responding. Restart docker engine?", "n")
+        if resp in ["y", "Y", True, "yes", "YES", "Yes", "true", "True"]:
+            pipe_cmd("killall Docker && open /Applications/Docker.app")
