@@ -20,7 +20,7 @@ try:
 except:
     from pandas.core.tools.datetimes import guess_datetime_format
 
-from pyemr.utils.config import cprint, get_datetime_string, get_staging_dir, color_text
+from pyemr.utils.config import color_text, get_datetime_string, get_staging_dir
 
 
 S3_CLIENT_TYPES = ["s3", "s3n", "s3a"]
@@ -32,15 +32,6 @@ def s3_path_exists(s3_path: str):
     Args:
       s3_path: str:
       s3_path: str:
-      s3_path: str:
-      s3_path: str:
-      s3_path: str:
-      s3_path: str:
-      s3_path: str:
-      s3_path: str:
-      s3_path: str:
-      s3_path: str:
-      s3_path: str:
 
     Returns:
       bool: True if file exists.
@@ -71,22 +62,6 @@ def download_file_from_s3(s3_path: str, local_path: str):
       local_path: str:
       s3_path: str:
       local_path: str:
-      s3_path: str:
-      local_path: str:
-      s3_path: str:
-      local_path: str:
-      s3_path: str:
-      local_path: str:
-      s3_path: str:
-      local_path: str:
-      s3_path: str:
-      local_path: str:
-      s3_path: str:
-      local_path: str:
-      s3_path: str:
-      local_path: str:
-      s3_path: str:
-      local_path: str:
 
     Returns:
 
@@ -134,6 +109,18 @@ def get_file_name(path: str) -> str:
       path: str:
       path: str:
       path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
+      path: str:
 
     Returns:
 
@@ -156,6 +143,18 @@ def get_s3_bucket(s3_path: str):
       s3_path: str:
       s3_path: str:
       s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
 
     Returns:
 
@@ -182,6 +181,18 @@ def get_s3_key(s3_path: str):
       s3_path: str:
       s3_path: str:
       s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
+      s3_path: str:
 
     Returns:
 
@@ -229,7 +240,7 @@ def upload_to_s3(
 
     s3_client = boto3.resource("s3")  # pylint: disable=C0103
 
-    #cprint(f"Uploading '{local_path}' to s3...")
+    # cprint(f"Uploading '{local_path}' to s3...")
 
     file_size = os.stat(local_path).st_size
 
@@ -258,7 +269,7 @@ def upload_to_s3(
         )
 
 
-def get_file_s3_path(local_file_path, datetime, suffix):
+def get_file_s3_path(local_file_path, date_time, suffix):
     """
 
     Args:
@@ -272,13 +283,13 @@ def get_file_s3_path(local_file_path, datetime, suffix):
     """
     file_name = local_file_path.split("/")[-1]
     staging_dir = get_staging_dir()
-    if datetime == "latest":
+    if date_time == "latest":
         return f"{staging_dir}/{suffix}/latest/{file_name}"
 
-    return f"{staging_dir}/{suffix}/datetime={datetime}/{file_name}"
+    return f"{staging_dir}/{suffix}/datetime={date_time}/{file_name}"
 
 
-def upload_to_s3_stage(in_path, datetime, suffix):
+def upload_to_s3_stage(in_path, date_time, suffix):
     """
 
     Args:
@@ -290,10 +301,10 @@ def upload_to_s3_stage(in_path, datetime, suffix):
 
     """
 
-    s3_path = get_file_s3_path(in_path, datetime, suffix)
+    s3_path = get_file_s3_path(in_path, date_time, suffix)
     upload_to_s3(in_path, s3_path)
 
-    if datetime != "latest":
+    if date_time != "latest":
         s3_path_latest = get_file_s3_path(in_path, "latest", suffix)
         copy_on_s3(s3_path, s3_path_latest)
         return s3_path_latest
@@ -560,19 +571,6 @@ def get_possible_more_recent_paths(path: str, n_days=30) -> List[str]:
       path: str:
       n_days: (Default value = 30)
       path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
-      path: str:
 
     Returns:
 
@@ -583,11 +581,13 @@ def get_possible_more_recent_paths(path: str, n_days=30) -> List[str]:
         periods=n_days // 3,
         freq="-1D",
     ).tolist()
+    
     past_n_days += pd.date_range(
         min(past_n_days),
         periods=n_days // 2,
         freq="-5D",
     ).tolist()
+    
     past_n_days += pd.date_range(
         min(past_n_days),
         periods=n_days // 3,
@@ -596,7 +596,7 @@ def get_possible_more_recent_paths(path: str, n_days=30) -> List[str]:
 
     date_finder = DateFinder()
     dates = date_finder.extract_date_strings(path)
-    for date_string, indices, captures in dates:
+    for date_string, _ , _ in dates:
         date_format = guess_datetime_format(date_string)
         if date_format:
             for date in past_n_days:
